%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Auxiliary function in Monte Carlo simulations for section A.7.1 of "Bootstrap Inference in Partially Identified Models: Coverage of the Identified Set"
%   by Federico A. Bugni
%   Submitted to Econometrica
%
%   Simulations for Design 1 and N = 100
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This function computes the subsampling criterion function;
function [Qn_value1,Qn_value2] = Qn_function_SS(SSdata,data,tn,OPTIONS);

if  mean(data(:,1)) - tn <= mean(data(:,2)) + tn; % In this case, the estimated identified set is non-empty;
    points = [mean(data(:,1)) - tn; mean(data(:,2)) + tn]; % The relevant starting points for maximization are the boundaries.    
    % The optimization problem will only have boundary constrains, given by the estimated identified set;
    LB = mean(data(:,1)) - tn;
    UB = mean(data(:,2)) + tn;
    
    % Maximization for subsampling 1;
    Qn_value1 = -10; % arbitrarily low initial value;
    
    for j=1:size(points,2);
        [optimizer,mQn_value,bandera] = fmincon('Qn_eval_MYB',points(j),[],[],[],[],LB,UB,[],OPTIONS,tn,mean(data),mean(SSdata),size(SSdata,1));
        % The objective function for SS1 is the same as when we compute the bootstrap, except that bootstrap sample is replaced by subsample sample
        % we minimize, instead of maximize;
        current_value = - mQn_value;

        % check the maximizer
        if current_value >= Qn_value1 & bandera > 0;
            Qn_value1 = current_value;
        end
    end
    
    % Maximization for subsampling 2;
    Qn_value2 = -10; % arbitrarily low initial value;
    for j=1:size(points,2);
        [optimizer,mQn_value,bandera] = fmincon('Qn_eval_SS2',points(j),[],[],[],[],LB,UB,[],OPTIONS,tn,mean(data),mean(SSdata),size(SSdata,1));
        % we minimize, instead of maximize;
        current_value = - mQn_value;

        % check the maximizer
        if current_value >= Qn_value2 & bandera > 0;
            Qn_value2 = current_value;
        end
    end
    
else % In this case, the estimated indetified set is empty.
    Qn_value1 = 0;
    Qn_value2 = 0;
end