%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Auxiliary function in Monte Carlo simulations for section A.7.1 of "Bootstrap Inference in Partially Identified Models: Coverage of the Identified Set"
%   by Federico A. Bugni
%   Submitted to Econometrica
%
%   Simulations for Design 1 and N = 1000
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This function computes the bootstrap criterion function;
function [Qn_value] = Qn_function_MYB(Bdata,data,tn,OPTIONS)

if  mean(data(:,1)) - tn <= mean(data(:,2)) + tn; % In this case, the estimated identified set is non-empty;
    points = [mean(data(:,1)) - tn; mean(data(:,2)) + tn]; % The relevant starting points for maximization are the boundaries.    
    % The optimization problem will only have boundary constrains, given by the estimated identified set;
    LB = mean(data(:,1)) - tn;
    UB = mean(data(:,2)) + tn;
    
    % Maximization for bootstrap;
    Qn_value = -10; % arbitrarily low initial value;
    
    for j=1:size(points,2);
        [optimizer,mQn_value,bandera] = fmincon('Qn_eval_MYB',points(j),[],[],[],[],LB,UB,[],OPTIONS,tn,mean(data),mean(Bdata),size(data,1));
        current_value = - mQn_value;

        % check the maximizer
        if current_value >= Qn_value & bandera>0;
            Qn_value = current_value;
        end
    end
else % In this case, the estimated indetified set is empty.
    Qn_value = 0;
end