%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Auxiliary function in Monte Carlo simulations for section A.7.1 of "Bootstrap Inference in Partially Identified Models: Coverage of the Identified Set"
%   by Federico A. Bugni
%   Submitted to Econometrica
%
%   Simulations for Design 1 and N = 1000
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This function computes the subsampling criterion function;
function [Qn_value1,Qn_value2] = Qn_function_SS(SSdata,data,tn,OPTIONS);

% Compute parameters for both optimizations
Ehat = mean(data);
EShat = mean(SSdata);
bN = size(SSdata,1);

% Maximization for subsampling 1;
% In this case, solution to the optimization is trivial;
theta  = max(Ehat(1) - tn,Ehat(2) - tn); % the optimum occurs at the boundary.

% Now compute the maximum value of the criterion function;
Qn_value1 = sqrt(bN)*( max(EShat(1)-Ehat(1),0)*(Ehat(1) - theta >= -tn) + max(EShat(2)-Ehat(2),0)*(Ehat(2) - theta >= -tn) );


% Maximization for subsampling 2;
points = max(Ehat(1) - tn,Ehat(2) - tn); % By the structure the criterion function, these constitute adequate starting points for the maximization.

 % Initalize values for maximization.   
Qn_value2 = -10; % Initialize arbitrary low value for maximization.
LB = max(Ehat(1) - tn,Ehat(2) - tn); % Constrains from the estimated identified set
UB = 3; % Constrains from the parameter space.
NONLCON = [];

% Implement the maximization.
[optimizer,mQn_value,bandera] = fmincon('Qn_eval_SS2',points,[],[],[],[],LB,UB,[],OPTIONS,tn,Ehat,EShat,bN);
current_value = - mQn_value;

% check the maximizer
if current_value >= Qn_value2 & bandera>0;
    Qn_value2 = current_value;
end