%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Auxiliary function in Monte Carlo simulations for section A.7.1 of "Bootstrap Inference in Partially Identified Models: Coverage of the Identified Set"
%   by Federico A. Bugni
%   Submitted to Econometrica
%
%   Simulations for Design 2 and N = 1000
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This function computes the subsampling criterion function;
function [Qn_value1,Qn_value2] = Qn_function_SS(SSdata,data,tn,OPTIONS);

% we first compute relevant parameters;
Ehat = mean(data);
ESShat = mean(SSdata);
points = max(Ehat(1) - tn,Ehat(2) - tn);
bN = size(SSdata,1);

% Maximization for subsampling 1:
% subsampling criterion function fo subsampling 1 is easy.
theta = points; % the lower bound is the maximizer;
Qn_value1 = sqrt(bN)*( max(ESShat(1)-Ehat(1),0)*(Ehat(1) - theta >= -tn) + max(ESShat(2)-Ehat(2),0)*(Ehat(2) - theta >= -tn) );

% Maximization for subsampling 2:
Qn_value2 = -10; % propose an arbitrary low starting value;
LB = max(Ehat(1)  - tn,Ehat(2)  - tn); % The lower bound is given by the estimate of the identified set;
UB = 3; % The upper bound comes from the parameter space;

[optimizer,mQn_value,bandera] = fmincon('Qn_eval_SS2',points,[],[],[],[],LB,UB,[],OPTIONS,tn,Ehat,ESShat,bN);
current_value = - mQn_value;

% check the maximizer;
if current_value >= Qn_value2 & bandera>0;
    Qn_value2 = current_value;
end