%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Monte Carlo simulations for section A.7.1 of "Bootstrap Inference in Partially Identified Models: Coverage of the Identified Set"
%   by Federico A. Bugni
%   Submitted to Econometrica
%
%   This program generates tables for designs 1 and 2
%   Note: this program requires that each of simulations have already been completed.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;
Ns = [100;1000];

for design = 1:2;
    for j = 1:size(Ns,1);
        % Construct table;
        eval(['cd design',num2str(design),'/N',num2str(Ns(j)),';']);
        eval(['table_design',num2str(design),'_N',num2str(Ns(j)),' = [ ];']);      
        load mc_results;
        
        for DGP = 1 : 4;
            aux_table = [];
            eval(['aux_table = [ aux_table ; mean([coverage_MYB_DGP',num2str(DGP),']) ];']);
            eval(['aux_table = [ aux_table ; mean([coverage_MYAA_DGP',num2str(DGP),']) ];']);
            for b = 1 : size(SSsize,1);
                eval(['aux_table = [ aux_table ; mean([coverage_SS1_DGP',num2str(DGP),'(:,5*(b-1)+1:5*(b-1)+5)]) ];']);
            end
            for b = 1 : size(SSsize,1);
                eval(['aux_table = [ aux_table ; mean([coverage_SS2_DGP',num2str(DGP),'(:,5*(b-1)+1:5*(b-1)+5)]) ];']);
            end
            eval(['table_design',num2str(design),'_N',num2str(Ns(j)),' = [ table_design',num2str(design),'_N',num2str(Ns(j)),' ; transpose(aux_table) ];']);
        end
        
        cd ..; cd ..;
    end
end

% express numbers in percentage and round numbers;
table_design1_N100 = round(1000*(table_design1_N100))/10;
table_design1_N1000 = round(1000*(table_design1_N1000))/10;
table_design2_N100 = round(1000*(table_design2_N100))/10;
table_design2_N1000 = round(1000*(table_design2_N1000))/10;

% display tables
disp('------------------------------------------');
disp(['Table 2 : Results of first Monte Carlo design with N = 100' ])
disp(' ')
disp([table_design1_N100(1:5,:)]);
disp('-')
disp([table_design1_N100(6:10,:)]);
disp('-')
disp([table_design1_N100(11:15,:)]);
disp('-')
disp([table_design1_N100(16:20,:)]);

disp('------------------------------------------');
disp(['Table 3 : Results of first Monte Carlo design with N = 1000' ])
disp(' ')
disp(' ')
disp([table_design1_N1000(1:5,:)]);
disp('-')
disp([table_design1_N1000(6:10,:)]);
disp('-')
disp([table_design1_N1000(11:15,:)]);
disp('-')
disp([table_design1_N1000(16:20,:)]);
disp('------------------------------------------');

disp('------------------------------------------');
disp(['Table 4 : Results of second Monte Carlo design with N = 100' ])
disp(' ')
disp([table_design2_N100(1:5,:)]);
disp('-')
disp([table_design2_N100(6:10,:)]);
disp('-')
disp([table_design2_N100(11:15,:)]);
disp('-')
disp([table_design2_N100(16:20,:)]);

disp('------------------------------------------');
disp(['Table 5 : Results of second Monte Carlo design with N = 1000' ])
disp(' ')
disp(' ')
disp([table_design2_N1000(1:5,:)]);
disp('-')
disp([table_design2_N1000(6:10,:)]);
disp('-')
disp([table_design2_N1000(11:15,:)]);
disp('-')
disp([table_design2_N1000(16:20,:)]);
disp('------------------------------------------');

save tables table*;