%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Auxiliary function in Monte Carlo simulations for section A.7.2 of "Bootstrap Inference in Partially Identified Models: Coverage of the Identified Set"
%   by Federico A. Bugni
%   Submitted to Econometrica
%
%   Simulations for Design 1
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Description: This function computes the objetive function of our asymptotic approximation criterion function.
function mQn_value = Qn_eval_MYAA(theta,Zdata,data,tn);

mtheta=zeros(6,1);
mtheta(1)= normcdf([1,0]*theta);
mtheta(2)= normcdf([1,0]*theta);
mtheta(3)= normcdf([0,1]*theta);
mtheta(4)= normcdf([0,1]*theta);
mtheta(5)= normcdf([1,1]*theta);
mtheta(6)= normcdf([1,1]*theta);

N1 = sum(data(:,7)==1);
N2 = sum(data(:,7)==2);
N3 = sum(data(:,7)==3);
N = N1 + N2 + N3;

E1=[mean(data(:,1))*N/N1,mean(data(:,2))*N/N1];
E2=[mean(data(:,3))*N/N2,mean(data(:,4))*N/N2];
E3=[mean(data(:,5))*N/N3,mean(data(:,6))*N/N3];

N1hat = sum(Zdata(:,7)==1);
N2hat = sum(Zdata(:,7)==2);
N3hat = sum(Zdata(:,7)==3);
Nhat = N1hat + N2hat + N3hat;

p1hat = N1hat/Nhat;
p2hat = N2hat/Nhat;
p3hat = N3hat/Nhat;

Qn_value =  sqrt(size(Zdata,1)) * (...
    max( mean( Zdata(:,1)) ,0 )*(  E1(1) - mtheta(1) >= -tn ) + ...
    max( mean(-Zdata(:,2)) ,0 )*( -E1(2) + mtheta(2) >= -tn ) + ...
    max( mean( Zdata(:,3)) ,0 )*(  E2(1) - mtheta(3) >= -tn ) + ...
    max( mean(-Zdata(:,4)) ,0 )*( -E2(2) + mtheta(4) >= -tn ) + ...
    max( mean( Zdata(:,5)) ,0 )*(  E3(1) - mtheta(5) >= -tn ) + ...
    max( mean(-Zdata(:,6)) ,0 )*( -E3(2) + mtheta(6) >= -tn ) );

% we minimize, instead of maximize;
mQn_value = - Qn_value;