%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Auxiliary function in Monte Carlo simulations for section A.7.2 of "Bootstrap Inference in Partially Identified Models: Coverage of the Identified Set"
%   by Federico A. Bugni
%   Submitted to Econometrica
%
%   Simulations for Design 4
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Description: This function computes the objetive function of our bootstrap criterion function.
function mQn_value = Qn_eval_MYB(theta,Bdata,data,tn);

mtheta=zeros(6,1);
mtheta(1)= normcdf([1,0]*theta);
mtheta(2)= normcdf([1,0]*theta);
mtheta(3)= normcdf([0,1]*theta);
mtheta(4)= normcdf([0,1]*theta);
mtheta(5)= normcdf([-1,0]*theta);
mtheta(6)= normcdf([-1,0]*theta);

N1 = sum(data(:,7)==1);
N2 = sum(data(:,7)==2);
N3 = sum(data(:,7)==3);
N = N1 + N2 + N3;

E1=[mean(data(:,1))*N/N1,mean(data(:,2))*N/N1];
E2=[mean(data(:,3))*N/N2,mean(data(:,4))*N/N2];
E3=[mean(data(:,5))*N/N3,mean(data(:,6))*N/N3];

N1hat = sum(Bdata(:,7)==1);
N2hat = sum(Bdata(:,7)==2);
N3hat = sum(Bdata(:,7)==3);
Nhat = N1hat + N2hat + N3hat;

p1hat = N1hat/Nhat;
p2hat = N2hat/Nhat;
p3hat = N3hat/Nhat;

Qn_value =  sqrt(size(Bdata,1)) * (...
    max( mean( Bdata(:,1)) - E1(1)*p1hat,0 )*(  E1(1) - mtheta(1) >= -tn ) + ...
    max( mean(-Bdata(:,2)) + E1(2)*p1hat,0 )*( -E1(2) + mtheta(2) >= -tn ) + ...
    max( mean( Bdata(:,3)) - E2(1)*p2hat,0 )*(  E2(1) - mtheta(3) >= -tn ) + ...
    max( mean(-Bdata(:,4)) + E2(2)*p2hat,0 )*( -E2(2) + mtheta(4) >= -tn ) + ...
    max( mean( Bdata(:,5)) - E3(1)*p3hat,0 )*(  E3(1) - mtheta(5) >= -tn ) + ...
    max( mean(-Bdata(:,6)) + E3(2)*p3hat,0 )*( -E3(2) + mtheta(6) >= -tn ) );

% we minimize, instead of maximize;
mQn_value = - Qn_value;