%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
%   Monte Carlo simulations for section A.7.2 of "Bootstrap Inference in Partially Identified Models: Coverage of the Identified Set"
%   by Federico A. Bugni
%   Submitted to Econometrica
%
%   This program generates tables for the four designs and saves them.
%   Note: this program requires that each of simulations have already been completed.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear;
save tables; % saves empty file

for design = 1 : 3;
    eval(['cd design',num2str(design)]);
    load mc_results
    table = mean(coverage_SS1(:,1:4)); % add results of subsampling approximation 1 with bn = n/3 (bn = 200);
    table = [table ; mean(coverage_SS1(:,5:8))]; % add results of subsampling approximation 1 with bn = n/2 (bn = 300);
    table = [table ; mean(coverage_SS2(:,1:4))]; % add results of subsampling approximation 2 with bn = n/3 (bn = 200);
    table = [table ; mean(coverage_SS2(:,5:8))]; % add results of subsampling approximation 2 with bn = n/2 (bn = 300);
    table = [table ; mean(coverage_MYB)]; % add results of our bootstrap approximation;
    table = [table ; mean(coverage_MYAA)]; % add results of our asymptotic approximation;
    
    % express in percentages and round the numbers
    table = round(1000*(table))/10;
    
    disp('------------------------------------------');
    disp(['Table ',num2str(6+design),': Results of Monte Carlo design ',num2str(design)])
    disp(' ')
    disp([table]);
    disp('------------------------------------------');

    eval(['table',num2str(design),' = table;']);
    cd ..
    save tables table* -append; % adds each table to the file.
    clear;
end

for design = 4;
    eval(['cd design',num2str(design)]);
    load mc_results
    table = mean(quantile_SS1(:,1:4)); % add results of subsampling approximation 1 with bn = n/3 (bn = 200);
    table = [table ; mean(quantile_SS1(:,5:8))]; % add results of subsampling approximation 1 with bn = n/2 (bn = 300);
    table = [table ; mean(quantile_SS2(:,1:4))]; % add results of subsampling approximation 2 with bn = n/3 (bn = 200);
    table = [table ; mean(quantile_SS2(:,5:8))]; % add results of subsampling approximation 2 with bn = n/2 (bn = 300);
    table = [table ; mean(quantile_MYB)]; % add results of our bootstrap approximation;
    table = [table ; mean(quantile_MYAA)]; % add results of our asymptotic approximation;
    
    % round the numbers
    table = round(100*(table))/100;
    
    disp('------------------------------------------');
    disp(['Table ',num2str(6+design),': Results of Monte Carlo design ',num2str(design)])
    disp(' ')
    disp([table]);
    disp('------------------------------------------');

    eval(['table',num2str(design),' = table;']);
    cd ..
    save tables table* -append; % adds each table to the file.
    clear;
end